@@ -1,11 +1,6 @@
 """
 SPARTN L-Band Correction receiver configuration dialog
 
-This dialog maintains its own threaded serial
-stream handler for incoming and outgoing Correction
-receiver (D9S) data (RXM-PMP), and must remain open for
-SPARTN passthrough to work.
-
 Created on 26 Jan 2023
 
 :author: semuadmin
@@ -31,7 +26,6 @@ from tkinter import (
     NORMAL,
     DISABLED,
 )
-from queue import Queue
 from PIL import ImageTk, Image
 from pyubx2 import (
     UBXMessage,
@@ -51,6 +45,7 @@ from pygpsclient.globals import (
     ICON_SOCKET,
     ENTCOL,
     CONNECTED_SPARTNLB,
+    CONNECTED_SPARTNIP,
     DISCONNECTED,
     NOPORTS,
     READONLY,
@@ -60,18 +55,19 @@ from pygpsclient.globals import (
     TIMEOUTS,
     SPARTN_EVENT,
     SPARTN_LBAND,
+    SPARTN_EOF_EVENT,
 )
 from pygpsclient.strings import (
     LBLSPARTNLB,
     CONFIGOK,
     CONFIGBAD,
+    DLGSPARTNWARN,
 )
 from pygpsclient.helpers import (
     valid_entry,
     VALINT,
 )
 from pygpsclient.serialconfig_frame import SerialConfigFrame
-from pygpsclient.stream_handler import StreamHandler
 
 U2MAX = 2e16 - 1
 U8MAX = 2e64 - 1
@@ -134,7 +130,6 @@ class SPARTNLBANDDialog(Frame):
         self._img_serial = ImageTk.PhotoImage(Image.open(ICON_SERIAL))
         self._img_socket = ImageTk.PhotoImage(Image.open(ICON_SOCKET))
         self._img_disconn = ImageTk.PhotoImage(Image.open(ICON_DISCONN))
-        self._stream_handler = StreamHandler(self)
         self._status = StringVar()
         self._spartn_freq = StringVar()
         self._spartn_schwin = StringVar()
@@ -148,6 +143,8 @@ class SPARTNLBANDDialog(Frame):
         self._spartn_outport = StringVar()
         self._spartn_enabledbg = IntVar()
         self._ports = INPORTS
+        self._settings = {}
+        self._connected = DISCONNECTED
 
         self._body()
         self._do_layout()
@@ -396,12 +393,19 @@ class SPARTNLBANDDialog(Frame):
         Connect to Correction receiver.
         """
 
+        if self.__app.rtk_conn_status == CONNECTED_SPARTNIP:
+            self.__container.set_status(
+                DLGSPARTNWARN.format("IP", "L-Band"),
+                "red",
+            )
+            return
+
         if self.serial_settings.status == NOPORTS:
             return
 
         # start serial stream thread
         self.__app.rtk_conn_status = CONNECTED_SPARTNLB
-        self._stream_handler.start_read_thread(self)
+        self.__app.spartn_stream_handler.start_read_thread(self._get_settings())
         self.__container.set_status(
             f"Connected to {self.serial_settings.port}:{self.serial_settings.port_desc} "
             + f"@ {self.serial_settings.bpsrate}",
@@ -409,24 +413,46 @@ class SPARTNLBANDDialog(Frame):
         )
         self.set_controls(CONNECTED_SPARTNLB)
 
-        # poll for config
         self._poll_config()
 
-    def on_disconnect(self):
+    def on_disconnect(self, msg: str = ""):
         """
-        Disconnect from Correction receiver.
+        Disconnect from L-Band Correction receiver.
+
+        :param str msg: optional disconnection message
         """
 
+        msg += "Disconnected"
         if self.__app.rtk_conn_status == CONNECTED_SPARTNLB:
-            if self._stream_handler is not None:
-                self._stream_handler.stop_read_thread()
+            if self.__app.spartn_stream_handler is not None:
+                self.__app.spartn_stream_handler.stop_read_thread()
                 self.__app.rtk_conn_status = DISCONNECTED
                 self.__container.set_status(
-                    "Disconnected",
+                    msg,
                     "red",
                 )
             self.set_controls(DISCONNECTED)
 
+    def _get_settings(self) -> dict:
+        """
+        Get settings dict.
+
+        :return: dictionary of settings for stream handler
+        :rtype: dict
+        """
+
+        return {
+            "owner": self,
+            "read_event": SPARTN_EVENT,
+            "eof_event": SPARTN_EOF_EVENT,
+            "inqueue": self.__app.spartn_inqueue,
+            "outqueue": self.__app.spartn_outqueue,
+            "socket_inqueue": self.__app.socket_inqueue,
+            "socket_outqueue": self.__app.socket_outqueue,
+            "serial_settings": self.serial_settings,
+            "in_filepath": "",
+        }
+
     def _format_cfgpoll(self) -> UBXMessage:
         """
         Format UBX CFG-VALGET message to poll Correction receiver
@@ -504,7 +530,6 @@ class SPARTNLBANDDialog(Frame):
         self.__container.set_status(f"{CFGSET} command sent", "green")
         self._lbl_send.config(image=self._img_pending)
 
-        # poll for config
         self._poll_config()
 
     def _poll_config(self):
@@ -564,6 +589,25 @@ class SPARTNLBANDDialog(Frame):
     # FOLLOWING METHODS REQUIRED BY STREAM_HANDLER
     # ============================================
 
+    @property
+    def conn_status(self) -> int:
+        """
+        Getter for connection status
+        (0 = disconnected, 1 = serial, 2 = socket, 4 = file).
+        """
+
+        return self.__app.rtk_conn_status
+
+    @conn_status.setter
+    def conn_status(self, status: int):
+        """
+        Setter for connection status.
+
+        :param int status: 0 = disconnected, 1 = serial, 2 = socket, 4 = file.
+        """
+
+        self.__app.rtk_conn_status = status
+
     def set_status(self, msg: str, color: str = "blue"):
         """
         Set status message.
@@ -584,16 +628,6 @@ class SPARTNLBANDDialog(Frame):
 
         self.__container.set_status(msg, color)
 
-    @property
-    def appmaster(self) -> object:
-        """
-        Getter for application master (Tk)
-
-        :return: reference to application master (Tk)
-        """
-
-        return self.__master
-
     @property
     def serial_settings(self) -> Frame:
         """
@@ -604,45 +638,3 @@ class SPARTNLBANDDialog(Frame):
         """
 
         return self._frm_spartn_serial
-
-    @property
-    def mode(self) -> int:
-        """
-        Getter for connection mode
-        (0 = disconnected, 1 = serial, 2 = socket, 4 = file).
-        """
-
-        return self.__app.rtk_conn_status
-
-    @property
-    def read_event(self) -> str:
-        """
-        Getter for type of event to be raised when data
-        is added to spartn_inqueue.
-        """
-
-        return SPARTN_EVENT
-
-    @property
-    def inqueue(self) -> Queue:
-        """
-        Getter for SPARTN input queue.
-        """
-
-        return self.__app.spartn_inqueue
-
-    @property
-    def outqueue(self) -> Queue:
-        """
-        Getter for SPARTN output queue.
-        """
-
-        return self.__app.spartn_outqueue
-
-    @property
-    def socketqueue(self) -> Queue:
-        """
-        Getter for socket input queue.
-        """
-
-        return self.__app.socket_inqueue
