@@ -117,7 +117,7 @@ class UBX_CFGVAL_Frame(Frame):
         """
 
         self.__app = app  # Reference to main application class
-        self.__master = self.__app.get_master()  # Reference to root class (Tk)
+        self.__master = self.__app.appmaster  # Reference to root class (Tk)
         self.__container = container
 
         Frame.__init__(self, self.__container.container, *args, **kwargs)
@@ -255,25 +255,25 @@ class UBX_CFGVAL_Frame(Frame):
         )
         self._scr_parmv.grid(column=4, row=2, rowspan=5, sticky=(N, S, E))
         self._scr_parmh.grid(column=1, row=7, columnspan=4, sticky=(W, E))
-        self._rad_cfgget.grid(column=0, row=8, padx=3, pady=0, sticky=(W))
-        self._rad_cfgset.grid(column=0, row=9, padx=3, pady=0, sticky=(W))
-        self._rad_cfgdel.grid(column=0, row=10, padx=3, pady=0, sticky=(W))
-        self._lbl_key.grid(column=1, row=8, padx=3, pady=0, sticky=(E))
-        self._lbl_keyid.grid(column=2, row=8, padx=3, pady=0, sticky=(W))
-        self._lbl_type.grid(column=3, row=8, padx=3, pady=0, sticky=(E))
-        self._lbl_att.grid(column=4, row=8, padx=3, pady=0, sticky=(W))
-        self._lbl_layer.grid(column=1, row=9, padx=3, pady=0, sticky=(E))
-        self._spn_layer.grid(column=2, row=9, padx=3, pady=0, sticky=(W))
-        self._lbl_val.grid(column=1, row=10, padx=3, pady=0, sticky=(E))
+        self._rad_cfgget.grid(column=0, row=8, padx=3, pady=0, sticky=W)
+        self._rad_cfgset.grid(column=0, row=9, padx=3, pady=0, sticky=W)
+        self._rad_cfgdel.grid(column=0, row=10, padx=3, pady=0, sticky=W)
+        self._lbl_key.grid(column=1, row=8, padx=3, pady=0, sticky=E)
+        self._lbl_keyid.grid(column=2, row=8, padx=3, pady=0, sticky=W)
+        self._lbl_type.grid(column=3, row=8, padx=3, pady=0, sticky=E)
+        self._lbl_att.grid(column=4, row=8, padx=3, pady=0, sticky=W)
+        self._lbl_layer.grid(column=1, row=9, padx=3, pady=0, sticky=E)
+        self._spn_layer.grid(column=2, row=9, padx=3, pady=0, sticky=W)
+        self._lbl_val.grid(column=1, row=10, padx=3, pady=0, sticky=E)
         self._ent_val.grid(
             column=2, row=10, columnspan=3, padx=3, pady=0, sticky=(W, E)
         )
 
         self._btn_send_command.grid(
-            column=3, row=12, rowspan=2, ipadx=3, ipady=3, sticky=(E)
+            column=3, row=12, rowspan=2, ipadx=3, ipady=3, sticky=E
         )
         self._lbl_send_command.grid(
-            column=4, row=13, rowspan=2, ipadx=3, ipady=3, sticky=(E)
+            column=4, row=13, rowspan=2, ipadx=3, ipady=3, sticky=E
         )
 
         (cols, rows) = self.grid_size()
